Actions, Resources, and Condition Keys for AWS Config - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS Config

AWS Config (service prefix: `config` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Config
- Resource Types Defined by AWS Config
- Condition Keys for AWS Config

## Actions Defined by AWS Config

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchGetAggregateResourceConfig | Returns the current configuration items for resources that are present in your AWS Config aggregator | Read | ConfigurationAggregator* |  |
BatchGetResourceConfig | Returns the current configuration for one or more requested resources | Read |  |  |
DeleteAggregationAuthorization | Deletes the authorization granted to the specified configuration aggregator account in a specified region | Write | AggregationAuthorization* |  |
DeleteConfigRule | Deletes the specified AWS Config rule and all of its evaluation results | Write | ConfigRule* |  |
DeleteConfigurationAggregator | Deletes the specified configuration aggregator and the aggregated data associated with the aggregator | Write | ConfigurationAggregator* |  |
DeleteConfigurationRecorder | Deletes the configuration recorder | Write |  |  |
DeleteConformancePack | Deletes the specified conformance pack and all the AWS Config rules and all evaluation results within that conformance pack. | Write |  |  |
DeleteDeliveryChannel | Deletes the delivery channel | Write |  |  |
DeleteEvaluationResults | Deletes the evaluation results for the specified Config rule | Write | ConfigRule* |  |
DeleteOrganizationConfigRule | Deletes the specified organization config rule and all of its evaluation results from all member accounts in that organization. | Write |  |  |
DeleteOrganizationConformancePack | Deletes the specified organization conformance pack and all of its evaluation results from all member accounts in that organization. | Write |  |  |
DeletePendingAggregationRequest | Deletes pending authorization requests for a specified aggregator account in a specified region | Write |  |  |
DeleteRemediationConfiguration | Deletes the remediation configuration | Write | RemediationConfiguration* |  |
DeleteRemediationExceptions | Deletes one or more remediation exceptions for specific resource keys for a specific AWS Config Rule. | Write |  |  |
DeleteRetentionConfiguration | Deletes the retention configuration | Write |  |  |
DeliverConfigSnapshot | Schedules delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel | Read |  |  |
DescribeAggregateComplianceByConfigRules | Returns a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules | List | ConfigurationAggregator* |  |
DescribeAggregationAuthorizations | Returns a list of authorizations granted to various aggregator accounts and regions | List |  |  |
DescribeComplianceByConfigRule | Indicates whether the specified AWS Config rules are compliant | List | ConfigRule* |  |
DescribeComplianceByResource | Indicates whether the specified AWS resources are compliant | List |  |  |
DescribeConfigRuleEvaluationStatus | Returns status information for each of your AWS managed Config rules | List | ConfigRule* |  |
DescribeConfigRules | Returns details about your AWS Config rules | List | ConfigRule* |  |
DescribeConfigurationAggregatorSourcesStatus | Returns status information for sources within an aggregator | List | ConfigurationAggregator* |  |
DescribeConfigurationAggregators | Returns the details of one or more configuration aggregators | List |  |  |
DescribeConfigurationRecorderStatus | Returns the current status of the specified configuration recorder | List |  |  |
DescribeConfigurationRecorders | Returns the name of one or more specified configuration recorders | List |  |  |
DescribeConformancePackCompliance | Returns compliance information for each rule in that conformance pack. | Read |  |  |
DescribeConformancePackStatus | Provides one or more conformance packs deployment status. | Read |  |  |
DescribeConformancePacks | Returns a list of one or more conformance packs. | Read |  |  |
DescribeDeliveryChannelStatus | Returns the current status of the specified delivery channel | List |  |  |
DescribeDeliveryChannels | Returns details about the specified delivery channel | List |  |  |
DescribeOrganizationConfigRuleStatuses | Provides organization config rule deployment status for an organization. | Read |  |  |
DescribeOrganizationConfigRules | Returns a list of organization config rules. | Read |  |  |
DescribeOrganizationConformancePackStatuses | Provides organization conformance pack deployment status for an organization. | Read |  |  |
DescribeOrganizationConformancePacks | Returns a list of organization conformance packs. | Read |  |  |
DescribePendingAggregationRequests | Returns a list of all pending aggregation requests | List |  |  |
DescribeRemediationConfigurations | Returns the details of one or more remediation configurations | List | RemediationConfiguration* |  |
DescribeRemediationExceptions | Returns the details of one or more remediation exceptions. | List |  |  |
DescribeRemediationExecutionStatus | Provides a detailed view of a Remediation Execution for a set of resources including state, timestamps and any error messages for steps that have failed | List | RemediationConfiguration* |  |
DescribeRetentionConfigurations | Returns the details of one or more retention configurations | List |  |  |
GetAggregateComplianceDetailsByConfigRule | Returns the evaluation results for the specified AWS Config rule for a specific resource in a rule | Read | ConfigurationAggregator* |  |
GetAggregateConfigRuleComplianceSummary | Returns the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator | Read | ConfigurationAggregator* |  |
GetAggregateDiscoveredResourceCounts | Returns the resource counts across accounts and regions that are present in your AWS Config aggregator | Read | ConfigurationAggregator* |  |
GetAggregateResourceConfig | Returns configuration item that is aggregated for your specific resource in a specific source account and region | Read | ConfigurationAggregator* |  |
GetComplianceDetailsByConfigRule | Returns the evaluation results for the specified AWS Config rule | Read | ConfigRule* |  |
GetComplianceDetailsByResource | Returns the evaluation results for the specified AWS resource | Read |  |  |
GetComplianceSummaryByConfigRule | Returns the number of AWS Config rules that are compliant and noncompliant, up to a maximum of 25 for each | Read |  |  |
GetComplianceSummaryByResourceType | Returns the number of resources that are compliant and the number that are noncompliant | Read |  |  |
GetConformancePackComplianceDetails | Returns compliance details of a conformance pack for all AWS resources that are monitered by conformance pack. | Read |  |  |
GetConformancePackComplianceSummary | Provides compliance summary for one or more conformance packs. | Read |  |  |
GetDiscoveredResourceCounts | Returns the resource types, the number of each resource type, and the total number of resources that AWS Config is recording in this region for your AWS account | Read |  |  |
GetOrganizationConfigRuleDetailedStatus | Returns detailed status for each member account within an organization for a given organization config rule. | Read |  |  |
GetOrganizationConformancePackDetailedStatus | Returns detailed status for each member account within an organization for a given organization conformance pack. | Read |  |  |
GetResourceConfigHistory | Returns a list of configuration items for the specified resource | Read |  |  |
ListAggregateDiscoveredResources | Accepts a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions | List | ConfigurationAggregator* |  |
ListDiscoveredResources | Accepts a resource type and returns a list of resource identifiers for the resources of that type | List |  |  |
ListTagsForResource | List the tags for AWS Config resource | List | AggregationAuthorization |  |
ConfigRule |  |
ConfigurationAggregator |  |
PutAggregationAuthorization | Authorizes the aggregator account and region to collect data from the source account and region | Write | AggregationAuthorization* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutConfigRule | Adds or updates an AWS Config rule for evaluating whether your AWS resources comply with your desired configurations | Write | ConfigRule* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutConfigurationAggregator | Creates and updates the configuration aggregator with the selected source accounts and regions | Write | ConfigurationAggregator* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutConfigurationRecorder | Creates a new configuration recorder to record the selected resource configurations | Write |  |  |
PutConformancePack | Creates or updates a conformance pack. | Write |  |  |
PutDeliveryChannel | Creates a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic | Write |  |  |
PutEvaluations | Used by an AWS Lambda function to deliver evaluation results to AWS Config | Write |  |  |
PutOrganizationConfigRule | Adds or updates organization config rule for your entire organization evaluating whether your AWS resources comply with your desired configurations. | Write |  |  |
PutOrganizationConformancePack | Adds or updates organization conformance pack for your entire organization evaluating whether your AWS resources comply with your desired configurations. | Write |  |  |
PutRemediationConfigurations | Adds or updates the remediation configuration with a specific AWS Config rule with the selected target or action | Write | RemediationConfiguration* |  |
PutRemediationExceptions | Adds or updates remediation exceptions for specific resources for a specific AWS Config rule. | Write |  |  |
PutRetentionConfiguration | Creates and updates the retention configuration with details about retention period (number of days) that AWS Config stores your historical information | Write |  |  |
SelectResourceConfig | Accepts a structured query language (SQL) SELECT command, performs the corresponding search, and returns resource configurations matching the properties | Read |  |  |
StartConfigRulesEvaluation | Evaluates your resources against the specified Config rules | Write | ConfigRule* |  |
StartConfigurationRecorder | Starts recording configurations of the AWS resources you have selected to record in your AWS account | Write |  |  |
StartRemediationExecution | Runs an on-demand remediation for the specified AWS Config rules against the last known remediation configuration | Write | RemediationConfiguration* |  |
StopConfigurationRecorder | Stops recording configurations of the AWS resources you have selected to record in your AWS account | Write |  |  |
TagResource | Associates the specified tags to a resource with the specified resourceArn | Tagging | AggregationAuthorization |  |
ConfigRule |  |
ConfigurationAggregator |  |
ConformancePack |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Deletes specified tags from a resource | Tagging | AggregationAuthorization |  |
ConfigRule |  |
ConfigurationAggregator |  |
ConformancePack |  |
| aws:TagKeys |

## Resource Types Defined by AWS Config

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
AggregationAuthorization | `arn:$ { Partition}:config:$ { Region}:$ { Account}:aggregation-authorization/$ { AggregatorAccount}/$ { AggregatorRegion}` | aws:ResourceTag/${TagKey}
ConfigurationAggregator | `arn:$ { Partition}:config:$ { Region}:$ { Account}:config-aggregator/$ { AggregatorId}` | aws:ResourceTag/${TagKey}
ConfigRule | `arn:$ { Partition}:config:$ { Region}:$ { Account}:config-rule/$ { ConfigRuleId}` | aws:ResourceTag/${TagKey}
ConformancePack | `arn:$ { Partition}:config:$ { Region}:$ { Account}:conformance-pack/$ { ConformancePackName}/$ { ConformancePackId}` | aws:ResourceTag/${TagKey}
OrganizationConfigRule | `arn:$ { Partition}:config:$ { Region}:$ { Account}:organization-config-rule/$ { OrganizationConfigRuleId}` |
OrganizationConformancePack | `arn:$ { Partition}:config:$ { Region}:$ { Account}:organization-conformance-pack/$ { OrganizationConformancePackId}` |
RemediationConfiguration | `arn:$ { Partition}:config:$ { Region}:$ { Account}:remediation-configuration/$ { RemediationConfigurationId}` |

## Condition Keys for AWS Config

AWS Config defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters actions based on the allowed set of values for each of the tags | String
aws:ResourceTag/$ { TagKey} | Filters actions based on tag-value assoicated with the resource | String
aws:TagKeys | Filters actions based on the presence of mandatory tags in the request | String